/******************************************************************************
*
* MODULE
*   TMS320F240 slave DSP user module template.
*
* FILE
*   usrdsp.h
*
* RELATED FILES
*   usrdsp.c
*
* DESCRIPTION
*   This module may contain user defined functions for the TMS320F240
*   slave DSP.
*   Each additional function must be registered in the fw240.c module by
*   using the function slvdsp_usrfct_install().
*
* AUTHOR(S)
*   M. Heier, V. Lang
*							&	L. BAGHLI (GREEN-UHP)
* dSPACE GmbH, Technologiepark 25, 33100 Paderborn, Germany
*
* $Workfile: Usrdsp.h $ $Revision: 3 $ $Date: 29.01.01 9:20 $
******************************************************************************/

#ifndef __USRDSP_H__
#define __USRDSP_H__


/*------------------- user firmware revision numbers ------------------------*/
#define USER_MAJOR_RELEASE      0
#define USER_MINOR_RELEASE      1
#define USER_SUBMINOR_RELEASE   2


#ifndef _DS1104
#include <slvdsp.h>
#endif /* !_DS1104 */

/******************************************************************************
* constants and defines
******************************************************************************/

/*------------- opcodes for user functions (0x0300 - 0x03FF -----------------*/

/* A unique opcode between 0x0300 - 0x03FF must be defined for each user
   function.

   example:
     #define SLVDSP_USRFCT_1 0x300
*/
     #define SLVDSP_USRFCT_SIMPLEPWMSYNCH		0x301
     #define SLVDSP_USRFCT_SIMPLEPWMUPDATE	0x302

/* parameters for user defined functions */
#define SLVDSP_USRFCT_SIMPLEPWMUPDATE_PCNT    3                      /* parameter count */
#define SLVDSP_USRFCT_SIMPLEPWMUPDATE_DUTY1_LOC 0                 /* phase 1 SCMPR1 duty cycle */
#define SLVDSP_USRFCT_SIMPLEPWMUPDATE_DUTY2_LOC 1                 /* phase 2 SCMPR2 duty cycle */
#define SLVDSP_USRFCT_SIMPLEPWMUPDATE_DUTY3_LOC 2                 /* phase 3 SCMPR3 duty cycle */
#define SLVDSP_USRFCT_SIMPLEPWMUPDATE_DINCNT  0                       /* no input data */
#define SLVDSP_USRFCT_SIMPLEPWMUPDATE_DOUTCNT 3                   /* output data count */


#ifndef _DS1104

/******************************************************************************
* global objects and variables
******************************************************************************/

#define slvdsp_usr_firmware_rev_set()           {  \
  user_major_release    = USER_MAJOR_RELEASE;      \
  user_minor_release    = USER_MINOR_RELEASE;      \
  user_subminor_release = USER_SUBMINOR_RELEASE; }

/******************************************************************************
* function prototypes
******************************************************************************/

/* User defined functions must read as follows. The parameter "index" is
   mandatory, even if not used.

   example:
     void slvdsp_usrfct_1(UInt16 index);
*/

     void slvdsp_usrfct_simplePWMsynch(UInt16 index);
     void slvdsp_usrfct_simplePWMupdate(UInt16 index);


#endif /* !_DS1104 */

#endif /* __USRDSP_H__ */
